<?php

/**
 * @file
 * Story Chief module admin settings.
 */

/**
 * Return the Story Chief global settings form.
 */
function storychief_admin_settings($form, &$form_state) {
  global $base_url;
  $form['connect'] = array(
    '#type' => 'fieldset',
    '#title' => t('Connect'),
    '#description' => '<p>'.t('Step 1: Connect your website to Story Chief').'</p>',
  );
  $form['connect']['storychief_key'] = array(
    '#type' => 'textfield',
    '#title' => 'Encryption key',
    '#required' => TRUE,
    '#default_value' => variable_get('storychief_key', ''),
    '#description' => t('Your encryption key is given when you add a Drupal destination on Story Chief'),
  );
  $form['connect']['website_url'] = array(
    '#type' => 'textfield',
    '#title' => 'Website url',
    '#disabled' => TRUE,
    '#value' => $base_url,
    '#description' => t('Copy past this url in your Drupal destination configuration on Story Chief'),
  );

  $node_types = node_type_get_types();
  $node_type_options = array();
  foreach ($node_types as $key => $node_type) {
    $node_type_options[$key] = $node_type->name;
  }

  $form['node_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Node settings'),
    '#description' => '<p>'.t('Step 2: Choose a node type where Story Chief must save stories to').'</p><label for="edit-storychief-node-type">Node type </label>',
  );
  $form['node_settings']['type'] = array(
    '#type' => 'container',
    '#attributes' => array('class' => array('container-inline')),
  );
  $form['node_settings']['type']['storychief_node_type'] = array(
    '#type' => 'select',
    '#empty_option' => t('- Choose node type -'),
    '#default_value' => variable_get('storychief_node_type', ''),
    '#options' => $node_type_options,
  );
  $form['node_settings']['type']['actions'] = array('#type' => 'actions');
  $form['node_settings']['type']['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Update'),
  );
  $storychief_node_type = variable_get('storychief_node_type', '');
  $form['fields'] = array(
    '#type' => 'fieldset',
    '#title' => t('Field mapping'),
  );


  if ($storychief_node_type != '') {
    $form['fields']['table'] = array(
      '#type' => 'container',
      '#prefix' => '<p>'.t("Last step! Let's map the Story Chief Story fields to your node fields:").'</p><table class="sticky-enabled tableheader-processed sticky-table"><thead></thead><tr><th>Source: Story Chief story</th><th width="50%">Target: '.t($node_type_options[$storychief_node_type]).' node</th></tr>',
      '#suffix' => '</table>',
    );
    if (module_exists('locale')) {
      $language_default = language_default('language');
      $translatable_node_type = variable_get('language_content_type_' . $storychief_node_type, 0);
      if ($translatable_node_type) {
        $languages = $languages = locale_language_list('name');
        $form['node_settings']['language']['storychief_node_language'] = array(
          '#title' => t('Language'),
          '#type' => 'select',
          '#default_value' => variable_get('storychief_node_language', $language_default),
          '#options' => array(LANGUAGE_NONE => t('Language neutral')) + $languages,
          '#description' => t('Choose the node language Story Chief needs to use to save stories'),
        );
      }
    }
    $form['fields']['table']['content'] = array(
      '#type' => 'container',
      '#prefix' => '<tr class="odd"><td><strong>Content & Excerpt <span class="form-required" title="This field is required.">*</span></strong><br /><div class="description"> '.t('This field is required and must be of type <i>@field</i>.<br />The excerpt will be inserted in the summary and can be used for teaser views.',array('@field' => t('Long text and summary'))).'</div></td><td>',
      'storychief_field_content' => array(
        '#type' => 'select',
        '#empty_option' => t('- Choose field -'),
        '#title' => t('Content'),
        '#title_display' => 'attribute',
        '#default_value' => variable_get('storychief_field_content', ''),
        '#disabled' => TRUE,
        '#required' => TRUE,
        '#options' => array(),
        '#description' => t('No <i>@field</i> field found on <i>@node</i> node',
          array(
            '@field' => t('Long text and summary'),
            '@node' => t($node_type_options[$storychief_node_type])
          )
        ),
      ),
      '#suffix' => '</td><tr>',
    );
    $form['fields']['table']['image'] = array(
      '#type' => 'container',
      '#prefix' => '<tr class="even"><td><strong>Cover image</strong><br /><div class="description"> '.t('The cover image for teaser views and/or header image.').'</div></td><td>',
      'storychief_field_image' => array(
        '#type' => 'select',
        '#empty_option' => t('- Choose field -'),
        '#title' => t('Cover image'),
        '#title_display' => 'attribute',
        '#default_value' => variable_get('storychief_field_image', ''),
        '#disabled' => TRUE,
        '#options' => array(),
        '#description' => t('No <i>@field</i> field found on <i>@node</i> node',
          array(
            '@field' => t('Image'),
            '@node' => t($node_type_options[$storychief_node_type])
          )
        ),
      ),
      '#suffix' => '</td><tr>',
    );

    $form['fields']['table']['tags'] = array(
      '#type' => 'container',
      '#prefix' => '<tr class="odd"><td><strong>Tags</strong><br /><div class="description"> '.t('Micro-categories for your story used to show related stories.').'</div></td><td>',
      'storychief_field_tags' => array(
        '#type' => 'select',
        '#empty_option' => t('- Choose field -'),
        '#title' => t('Tags'),
        '#title_display' => 'attribute',
        '#default_value' => variable_get('storychief_field_tags', ''),
        '#disabled' => TRUE,
        '#options' => array(),
        '#description' => t('No <i>@field</i> field with multiple values found on <i>@node</i> node',
          array(
            '@field' => t('Term reference'),
            '@node' => t($node_type_options[$storychief_node_type])
          )
        ),
      ),
      '#suffix' => '</td><tr>',
    );

    $form['fields']['table']['category'] = array(
      '#type' => 'container',
      '#prefix' => '<tr class="even"><td><strong>Category</strong><br /><div class="description"> '.t('The general topic the story can be classified in.<br />Readers can browse specific categories to see all stories in the category.').'</div></td><td>',
      'storychief_field_category' => array(
        '#type' => 'select',
        '#empty_option' => t('- Choose field -'),
        '#title' => t('Category'),
        '#title_display' => 'attribute',
        '#default_value' => variable_get('storychief_field_category', ''),
        '#disabled' => TRUE,
        '#options' => array(),
        '#description' => t('No <i>@field</i> field found on <i>@node</i> node',
          array(
            '@field' => t('Term reference'),
            '@node' => t($node_type_options[$storychief_node_type])
          )
        ),
      ),
      '#suffix' => '</td><tr>',
    );

    $fields_info = field_info_instances('node', NULL, $storychief_node_type);
    $storychief_fields = array();
    foreach ($fields_info as $bundle => $fields) {
      foreach ($fields as $field_name => $field) {
        $field_info = field_info_field($field_name);
        if ($field['deleted'] == '0') {
          $storychief_field_value = $field_name . ' (' . t($field['label'] . ')');
          switch ($field_info['type']) {
            case 'image':
              $storychief_fields['image'][$field_name] = $storychief_field_value;
              break;
            case 'text_with_summary':
              $storychief_fields['content'][$field_name] = $storychief_field_value;
              break;
            case 'taxonomy_term_reference':
              if ($field_info['cardinality'] == '-1' || (int) $field_info['cardinality'] > 1) {
                $storychief_fields['tags'][$field_name] = $storychief_field_value;
              }
              $storychief_fields['category'][$field_name] = $storychief_field_value;
              break;
          }
        }

      }
    }

    foreach ($storychief_fields as $storychief_field => $storychief_field_options) {
      $form['fields']['table'][$storychief_field]['storychief_field_' . $storychief_field]['#options'] = $storychief_field_options;
      unset($form['fields']['table'][$storychief_field]['storychief_field_' . $storychief_field]['#disabled']);
      unset($form['fields']['table'][$storychief_field]['storychief_field_' . $storychief_field]['#description']);
    }
  }
  else {
    $form['fields']['empty'] = array(
      '#type' => 'markup',
      '#markup' => '<p><i>You need to select a node type before you can start mapping your fields</i></p>',
    );
  }

  return system_settings_form($form);
}
